searchNodes=[{"doc":"Forgery is a slim yet extensible data generator in Elixir. Forgery provides a few simple APIs to work with. To get started, you need to implement the make/2 callback: defmodule User do defstruct [:id, :name, :password] end defmodule MyFactory do use Forgery def make(:user, fields) do fields |&gt; put_new_field(:id, lazy(make_unique_integer())) |&gt; put_new_field(:name, &amp;(&quot;user#&quot; &lt;&gt; Integer.to_string(&amp;1.id))) |&gt; create_struct(User) end end iex&gt; import MyFactory iex&gt; iex&gt; %User{} = make(:user) iex&gt; %User{id: 42, name: &quot;user#42&quot;} = make(:user, id: 42) iex&gt; [%User{}, %User{}] = make_many(:user, 2) And just as simple as that! Ecto integration Forgery was built with easy Ecto integration in mind, though not limiting to it. For example if you use Ecto and have MyRepo. You can add a function, says insert!, into the factory: defmodule MyFactory do def insert!(factory_name, fields \\ %{}) do factory_name |&gt; make(fields) |&gt; MyRepo.insert!() end def insert_many!(factory_name, amount, fields \\ %{}) when amount &gt;= 1 do [%schema{} | _] = entities = make_many(factory_name, amount, fields) {_, persisted_entities} = MyRepo.insert_all(schema, entities, returning: true) persisted_entities end end user = insert!(:user) users = insert_many!(:user, 10, %{password: &quot;1234567890&quot;})","ref":"Forgery.html","title":"Forgery","type":"behaviour"},{"doc":"Create struct of module from fields. See Kernel.struct!/2 for more information. iex&gt; create_struct(%{id: 1, name: &quot;John&quot;, password: &quot;123456&quot;}, User) %User{id: 1, password: &quot;123456&quot;, name: &quot;John&quot;}","ref":"Forgery.html#create_struct/2","title":"Forgery.create_struct/2","type":"function"},{"doc":"Wraps the given expr into an anonymous function. It is equivalent to fn _ -&gt; expr end.","ref":"Forgery.html#lazy/1","title":"Forgery.lazy/1","type":"macro"},{"doc":"Makes data from the given factory. The implementation of this callback should take in the factory name, as well and fields.","ref":"Forgery.html#c:make/2","title":"Forgery.make/2","type":"callback"},{"doc":"Make multiple data from the given factory. This function is roughly equivalent to: Enum.map(1..amount, fn _ -&gt; make(factory_name) end) Example make_many(:users, 3) [ %User{id: 3, password: nil, name: &quot;user#3&quot;}, %User{id: 5, password: nil, name: &quot;user#5&quot;}, %User{id: 7, password: nil, name: &quot;user#7&quot;} ]","ref":"Forgery.html#c:make_many/3","title":"Forgery.make_many/3","type":"callback"},{"doc":"Returns monotonically increasing unique integer. It would be useful when it comes to generate unique serial IDs.","ref":"Forgery.html#make_unique_integer/0","title":"Forgery.make_unique_integer/0","type":"function"},{"doc":"Lazily evaluates value_setter and puts the result into key if it does not exist in fields. The value_setter function receives fields as an argument. iex&gt; make_foo = fn _ -&gt; raise(&quot;I am invoked&quot;) end iex&gt; fields = %{foo: 1} iex&gt; put_new_field(fields, :foo, make_foo) %{foo: 1} iex&gt; put_new_field(fields, :bar, &amp;(&amp;1.foo + 100)) %{foo: 1, bar: 101} There is also helper macro lazy/1: iex&gt; fields = %{foo: 2} iex&gt; put_new_field(fields, :foo, lazy(10 * 10)) %{foo: 2}","ref":"Forgery.html#put_new_field/3","title":"Forgery.put_new_field/3","type":"function"},{"doc":"","ref":"Forgery.html#t:factory_name/0","title":"Forgery.factory_name/0","type":"type"},{"doc":"Forgery Forgery is a slim yet extensible data generator in Elixir.","ref":"readme.html","title":"Forgery","type":"extras"},{"doc":"def deps() do [{:forgery, &quot;~&gt; 0.1&quot;}] end","ref":"readme.html#installation","title":"Forgery - Installation","type":"extras"},{"doc":"Full documentation can be found at https://hexdocs.pm/forgery. Forgery provides a few simple APIs to work with: defmodule User do defstruct [:id, :name, :password] end defmodule MyFactory do use Forgery def make(:user, fields) do fields |&gt; put_new_field(:id, lazy(make_unique_integer())) |&gt; put_new_field(:name, &amp;(&quot;user#&quot; &lt;&gt; Integer.to_string(&amp;1.id))) |&gt; create_struct(User) end end iex&gt; import MyFactory iex&gt; iex&gt; %User{} = make(:user) iex&gt; %User{id: 42, name: &quot;user#42&quot;} = make(:user, id: 42) iex&gt; [%User{}, %User{}] = make_many(:user, 2) And just as simple as that!","ref":"readme.html#overview","title":"Forgery - Overview","type":"extras"},{"doc":"Forgery was built with easy Ecto integration in mind, though not limiting to it. For example you use Ecto and have MyRepo. You can add a function, says insert! and insert_many!, into the factory: defmodule MyFactory do def insert!(factory_name, fields \\\\ %{}) do factory_name |&gt; make(fields) |&gt; MyRepo.insert!() end def insert_many!(factory_name, amount, fields \\\\ %{}) when amount &gt;= 1 do [%schema{} | _] = entities = make_many(factory_name, amount, fields) {^amount, persisted_entities} = MyRepo.insert_all(schema, entities, returning: true) persisted_entities end end user = insert!(:user) users = insert_many!(:user, 10, %{password: &quot;1234567890&quot;})","ref":"readme.html#ecto-integration","title":"Forgery - Ecto integration","type":"extras"},{"doc":"This software is licensed under the ISC license.","ref":"readme.html#licensing","title":"Forgery - Licensing","type":"extras"},{"doc":"Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Breaking changes: Changed Forgery.put_new_field/3 to be a plain function that accepts anonymous functions. Infroduced Forgery.lazy/1 to make Forgery.put_new_field/3 usage more streamlined.","ref":"changelog.html#v0-2-0","title":"Changelog - v0.2.0","type":"extras"},{"doc":"Initial release.","ref":"changelog.html#v0-1-0","title":"Changelog - v0.1.0","type":"extras"}]